# Modeling: User Group (Meta Model V3 )
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/user-group-modeling-v3#overview)
  * [How to Model User Groups](https://help.sap.com/docs/leanix/ea/user-group-modeling-v3#how-to-model-user-groups)


The User Group Fact Sheet is an essential part of LeanIX's approach to representing business architecture. Often customers use it combined either with Business Capabilities or with Processes to obtain an Application Matrix report which is perfectly suited to identify possible synergies or gaps in the application landscape.
